.. _data:


Data Representation
*******************

.. currentmodule:: torchkge.data

.. automodule:: torchkge.data.KnowledgeGraph

Knowledge Graph
---------------
.. autoclass:: torchkge.data.KnowledgeGraph.KnowledgeGraph
    :members:

Small KG
--------

.. autoclass:: torchkge.data.KnowledgeGraph.SmallKG
    :members:
